#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 process-extras
version:              0.7.4
visibility:           public
id:                   process-extras-0.7.4-CKJqOJCm6OP1UfTzItmPPw
key:                  process-extras-0.7.4-CKJqOJCm6OP1UfTzItmPPw
license:              MIT
maintainer:           David Fox <dsf@seereason.com>
author:               David Lazar, Bas van Dijk, David Fox
homepage:             https://github.com/seereason/process-extras
synopsis:             Process extras
description:
    Extends <http://hackage.haskell.org/package/process>.
    Read process input and output as ByteStrings or
    Text, or write your own ProcessOutput instance.
    Lazy process input and output.  ProcessMaker class
    for more flexibility in the process creation API.

category:             System
abi:                  d24c47c2d9d8e0f47cd7358b9d596eaa
exposed:              True
exposed-modules:
    System.Process.ByteString System.Process.ByteString.Lazy
    System.Process.Chars System.Process.Common System.Process.ListLike
    System.Process.Run System.Process.Text System.Process.Text.Builder
    System.Process.Text.Lazy

hidden-modules:       Utils
import-dirs:          /usr/lib/ghc-8.10.5/site-local/process-extras-0.7.4
library-dirs:         /usr/lib/ghc-8.10.5/site-local/process-extras-0.7.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/process-extras-0.7.4
hs-libraries:         HSprocess-extras-0.7.4-CKJqOJCm6OP1UfTzItmPPw
depends:
    ListLike-4.7.4-2Tn8j7Cp580LIYHlUwQSaP base-4.14.2.0
    bytestring-0.10.12.0 data-default-0.7.1.1-5u8NwVJ9HGT30K0bkKsBOX
    deepseq-1.4.4.0 generic-deriving-1.14-15FNbtSLqa6F3AOxs0dmDl
    mtl-2.2.2 process-1.6.9.0 text-1.2.4.1

haddock-interfaces:
    /usr/share/doc/haskell-process-extras/html/process-extras.haddock

haddock-html:         /usr/share/doc/haskell-process-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

